@@ -8,6 +8,7 @@
  */
 
 package org.gnu.gnome;
+import org.gnu.glib.Handle;
 import org.gnu.glib.Type;
 /**
  *
@@ -17,7 +18,7 @@ public class CanvasClipgroup extends CanvasGroup {
 	 * Constructs an instance of CanvasClipgroup from a native widget resource.
 	 * @param handle The handle to the native widget.
 	 */
-	CanvasClipgroup(int handle) {
+	CanvasClipgroup(Handle handle) {
 		super(handle);
 	}
 
@@ -28,11 +29,7 @@ public class CanvasClipgroup extends CanvasGroup {
 		return new Type(gnome_canvas_clipgroup_get_type());
 	}
 
-	/****************************************
-	 * BEGINNING OF GENERATED CODE
-	 ****************************************/
+
 	native static final protected int gnome_canvas_clipgroup_get_type();
-	/****************************************
-	 * END OF GENERATED CODE
-	 ****************************************/
+
 }
