@@ -9,6 +9,7 @@
 
 package org.gnu.gnome;
 import org.gnu.glib.GObject;
+import org.gnu.glib.Handle;
 import org.gnu.glib.Type;
 import org.gnu.gtk.GtkObject;
 /**
@@ -24,7 +25,7 @@ public class CanvasItem extends GtkObject {
 	 * Constructs an instance of CanvasItem from a native widget resource.
 	 * @param handle The handle to the native widget.
 	 */
-	CanvasItem(int handle) {
+	CanvasItem(Handle handle) {
 		super(handle);
 	}
 
@@ -49,8 +50,8 @@ public class CanvasItem extends GtkObject {
 	 * @return The parent canvas.
 	 */
 	public Canvas getCanvas() {
-		int hndl = getCanvas(getHandle());
-		GObject obj = retrieveGObject(hndl);
+		Handle hndl = getCanvas(getHandle());
+		GObject obj = getGObjectFromHandle(hndl);
 		if (null != obj)
 			return (Canvas)obj;
 		return new Canvas(hndl);
@@ -61,8 +62,8 @@ public class CanvasItem extends GtkObject {
 	 * @return The parent cavas group.
 	 */
 	public CanvasGroup getParent() {
-		int hndl = getParent(getHandle());
-		GObject obj = retrieveGObject(hndl);
+		Handle hndl = getParent(getHandle());
+		GObject obj = getGObjectFromHandle(hndl);
 		if (null != obj)
 			return (CanvasGroup)obj;
 		return new CanvasGroup(hndl);
@@ -164,32 +165,28 @@ public class CanvasItem extends GtkObject {
 		return new Type(gnome_canvas_item_get_type());
 	}
 
-	/****************************************
-	 * BEGINNING OF GENERATED CODE
-	 ****************************************/
-	native static final protected int getCanvas(int cptr);
-	native static final protected int getParent(int cptr);
-	native static final protected double getX1(int cptr);
-	native static final protected double getY1(int cptr);
-	native static final protected double getX2(int cptr);
-	native static final protected double getY2(int cptr);
+
+	native static final protected Handle getCanvas(Handle cptr);
+	native static final protected Handle getParent(Handle cptr);
+	native static final protected double getX1(Handle cptr);
+	native static final protected double getY1(Handle cptr);
+	native static final protected double getX2(Handle cptr);
+	native static final protected double getY2(Handle cptr);
 	native static final protected int gnome_canvas_item_get_type();
-	native static final protected void gnome_canvas_item_move(int item, double dx, double dy);
-	native static final protected void gnome_canvas_item_affine_relative(int item, double[] affine);
-	native static final protected void gnome_canvas_item_affine_absolute(int item, double[] affine);
-	native static final protected void gnome_canvas_item_raise(int item, int position);
-	native static final protected void gnome_canvas_item_raise_to_top(int item);
-	native static final protected void gnome_canvas_item_lower(int item, int positions);
-	native static final protected void gnome_canvas_item_lower_to_bottom(int item);
-	native static final protected void gnome_canvas_item_show(int item);
-	native static final protected void gnome_canvas_item_hide(int item);
-	native static final protected int gnome_canvas_item_grab(int item, int event_mask, int cursor, int etime);
-	native static final protected void gnome_canvas_item_ungrab(int item, int etime);
-	native static final protected void gnome_canvas_item_reparent(int item, int new_group);
-	native static final protected void gnome_canvas_item_grab_focus(int item);
-	native static final protected void gnome_canvas_item_request_update(int item);
-	native static final protected int gnome_canvas_item_new(int group, int type);
-	/****************************************
-	 * END OF GENERATED CODE
-	 ****************************************/
+	native static final protected void gnome_canvas_item_move(Handle item, double dx, double dy);
+	native static final protected void gnome_canvas_item_affine_relative(Handle item, double[] affine);
+	native static final protected void gnome_canvas_item_affine_absolute(Handle item, double[] affine);
+	native static final protected void gnome_canvas_item_raise(Handle item, int position);
+	native static final protected void gnome_canvas_item_raise_to_top(Handle item);
+	native static final protected void gnome_canvas_item_lower(Handle item, int positions);
+	native static final protected void gnome_canvas_item_lower_to_bottom(Handle item);
+	native static final protected void gnome_canvas_item_show(Handle item);
+	native static final protected void gnome_canvas_item_hide(Handle item);
+	native static final protected int gnome_canvas_item_grab(Handle item, int event_mask, Handle cursor, int etime);
+	native static final protected void gnome_canvas_item_ungrab(Handle item, int etime);
+	native static final protected void gnome_canvas_item_reparent(Handle item, Handle new_group);
+	native static final protected void gnome_canvas_item_grab_focus(Handle item);
+	native static final protected void gnome_canvas_item_request_update(Handle item);
+	native static final protected Handle gnome_canvas_item_new(Handle group, int type);
+
 }
